/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Color;
import java.awt.Graphics2D;



import org.gfxtest.framework.PrintTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test suite checks basic functionality of built-in printing support.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.PRINT_TEST)
@GraphicsPrimitive(GraphicsPrimitives.LINE)
@RenderStyle(RenderStyles.NORMAL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class PrintTestBasic extends PrintTest
{

    /**
     * Test basic behavior of method Graphics.drawLine().
     *
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLine1(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);

        // draw one diagonal line
        graphics.drawLine(0, 0, image.getWidth(), image.getHeight());

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     *
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLine2(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);

        // draw two diagonals along the whole test image
        graphics.drawLine(0, image.getHeight(), image.getWidth(), 0);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     *
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLines(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);

        // image width and height
        final int width = image.getWidth();
        final int height = image.getHeight();

        // horizontal coordinates of line endpoints
        int x1 = 0;
        int x2 = width;

        // draw all lines onto a paper
        for (int y = 0; y < height; y += VERTICAL_STEP)
        {
            graphics.drawLine(x1, y, x2, y);
            // compute new horizontal coordinates of line endpoints
            x1 = Math.min(width / 2 - 10, x1 + 5);
            x2 = Math.max(width / 2 + 10, x2 - 5);
        }

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     *
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLines(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);

        // image width and height
        final int width = image.getWidth();
        final int height = image.getHeight();

        // vertical coordinates of line endpoints
        int y1 = 0;
        int y2 = height;

        // draw all lines onto a paper
        for (int x = 0; x < width; x += HORIZONTAL_STEP)
        {
            graphics.drawLine(x, y1, x, y2);
            // compute new vertical coordinates of line endpoints
            y1 = Math.min(height / 2 - 10, y1 + 5);
            y2 = Math.max(height / 2 + 10, y2 - 5);
        }

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new PrintTestBasic().runTestSuite(args);
    }
}
